:orphan:

.. currentmodule:: obspy.core.event.header
.. automodule:: obspy.core.event.header
    :members:

    .. comment to end block

    Variables
    ---------
    .. autosummary::
       :toctree: autogen
       :nosignatures:

       AmplitudeCategory
       AmplitudeUnit
       DataUsedWaveType
       EvaluationMode
       EvaluationStatus
       EventDescriptionType
       EventType
       EventTypeCertainty
       MTInversionType
       MomentTensorCategory
       OriginDepthType
       OriginType
       OriginUncertaintyDescription
       PickOnset
       PickPolarity
       SourceTimeFunctionType

    .. comment to end block
